root_as_city_feature

Function root_as_city_feature 

pub fn root_as_city_feature(
    buf: &[u8],
) -> Result<CityFeature<'_>, InvalidFlatbuffer>
Verifies that a buffer of bytes contains a CityFeature and returns it. Note that verification is still experimental and may not catch every error, or be maximally performant. For the previous, unchecked, behavior use root_as_city_feature_unchecked.