Module key

Module key 

Structs

FixedStringKey
A fixed-size key based on a string, suitable for use in the StaticBTree.

Enums

KeyType
Enum to hold different key types supported by the system

Traits

Key
Trait defining requirements for keys used in the StaticBTree.
Max
Trait for types that have a maximum representable value.
Min