pub trait Max {
// Required method
fn max_value() -> Self;
}Expand description
Trait for types that have a maximum representable value.
This trait allows retrieval of the maximum value for a type, which is useful for B-tree operations like range queries and bounds checking.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.