StreamMultiIndex

Struct StreamMultiIndex 

pub struct StreamMultiIndex { /* private fields */ }
Container for multiple stream indices with different key types

Implementations

Source

impl StreamMultiIndex

pub fn new() -> Self

Create a new empty multi-index

pub fn add_index<K: Key + 'static>( &mut self, field: String, index: StreamIndex<K>, )

Generic method to add an index for any supported key type

pub fn add_string_index20( &mut self, field: String, index: StreamIndex<FixedStringKey<20>>, length: u64, )

Add a string index with key size 20

pub fn add_string_index50( &mut self, field: String, index: StreamIndex<FixedStringKey<50>>, length: u64, )

Add a string index with key size 50

pub fn add_string_index100( &mut self, field: String, index: StreamIndex<FixedStringKey<100>>, length: u64, )

Add a string index with key size 100

pub fn add_i8_index( &mut self, field: String, index: StreamIndex<i8>, length: u64, )

Add an i8 index

pub fn add_u8_index( &mut self, field: String, index: StreamIndex<u8>, length: u64, )

Add a u8 index

pub fn add_i16_index( &mut self, field: String, index: StreamIndex<i16>, length: u64, )

Add an i16 index

pub fn add_u16_index( &mut self, field: String, index: StreamIndex<u16>, length: u64, )

Add a u16 index

pub fn add_i32_index( &mut self, field: String, index: StreamIndex<i32>, length: u64, )

Add an i32 index

pub fn add_i64_index( &mut self, field: String, index: StreamIndex<i64>, length: u64, )

Add an i64 index

pub fn add_u32_index( &mut self, field: String, index: StreamIndex<u32>, length: u64, )

Add a u32 index

pub fn add_u64_index( &mut self, field: String, index: StreamIndex<u64>, length: u64, )

Add a u64 index

pub fn add_f32_index( &mut self, field: String, index: StreamIndex<OrderedFloat<f32>>, length: u64, )

Add a float32 index

pub fn add_f64_index( &mut self, field: String, index: StreamIndex<OrderedFloat<f64>>, length: u64, )

Add a float64 index

pub fn add_bool_index( &mut self, field: String, index: StreamIndex<bool>, length: u64, )

Add a boolean index

pub fn add_datetime_index( &mut self, field: String, index: StreamIndex<DateTime<Utc>>, length: u64, )

Add a datetime index

pub fn query( &self, reader: &mut dyn ReadSeek, conditions: &[QueryCondition], ) -> Result<Vec<u64>>

Execute a heterogeneous query with different key types using a reader