FcbReader

Struct FcbReader 

pub struct FcbReader<R> { /* private fields */ }

Implementations

Source

impl<R: Read + Seek> FcbReader<R>

pub fn select_attr_query( self, query: AttrQuery, ) -> Result<FeatureIter<R, Seekable>>

Source

impl<R: Read> FcbReader<R>

pub fn select_attr_query_seq( self, query: AttrQuery, ) -> Result<FeatureIter<R, NotSeekable>>

Source

impl<R: Read> FcbReader<R>

pub fn open(reader: R) -> Result<FcbReader<R>, Error>

pub unsafe fn open_unchecked(reader: R) -> Result<FcbReader<R>, Error>

Open a reader without verifying the FlatBuffers data.

Safety

This function skips FlatBuffers verification. The caller must ensure that the input data is valid and properly formatted to avoid undefined behavior.

pub fn select_all_seq(self) -> Result<FeatureIter<R, NotSeekable>, Error>

pub fn select_query_seq( self, query: Query, ) -> Result<FeatureIter<R, NotSeekable>, Error>

Source

impl<R: Read + Seek> FcbReader<R>

pub fn select_all(self) -> Result<FeatureIter<R, Seekable>, Error>

pub fn select_query( self, query: Query, limit: Option<usize>, offset: Option<usize>, ) -> Result<FeatureIter<R, Seekable>, Error>

Source

impl<R: Read> FcbReader<R>

pub fn header(&self) -> Header<'_>

pub fn root_attr_schema( &self, ) -> Option<Vector<'_, ForwardsUOffset<Column<'_>>>>