pub enum Error {
Show 19 variants
MissingMagicBytes,
NoIndex,
AttributeIndexNotFound,
AttributeIndexSizeOverflow,
NoColumnsInHeader,
MissingRequiredField(String),
IllegalHeaderSize(usize),
InvalidFlatbuffer(InvalidFlatbuffer),
IoError(Error),
JsonError(Error),
RtreeError(Error),
UnsupportedColumnType(String),
InvalidAttributeValue {
msg: String,
},
IndexCreationError(String),
QueryExecutionError(String),
HttpClient(HttpError),
CityJson {
source: CjError,
},
CjseqError {
source: CjseqError,
},
StaticBTree {
source: Error,
},
}Expand description
The main error type for the FCB Core library. This enum represents all possible errors that can occur during FCB operations.
Variants
MissingMagicBytes
NoIndex
AttributeIndexNotFound
AttributeIndexSizeOverflow
NoColumnsInHeader
MissingRequiredField(String)
IllegalHeaderSize(usize)
InvalidFlatbuffer(InvalidFlatbuffer)
IoError(Error)
JsonError(Error)
RtreeError(Error)
UnsupportedColumnType(String)
InvalidAttributeValue
IndexCreationError(String)
QueryExecutionError(String)
HttpClient(HttpError)
CityJson
Fields

source: CjErrorCjseqError
Fields

source: CjseqErrorStaticBTree
Implementations
Sourceimpl Error
impl Error
Sourcepub fn is_io_error(&self) -> bool
pub fn is_io_error(&self) -> bool
Returns true if the error is related to IO operations
Sourcepub fn is_format_error(&self) -> bool
pub fn is_format_error(&self) -> bool
Returns true if the error is related to data format
Sourcepub fn is_validation_error(&self) -> bool
pub fn is_validation_error(&self) -> bool
Returns true if the error is related to validation
Sourcepub fn is_index_error(&self) -> bool
pub fn is_index_error(&self) -> bool
Returns true if the error is related to index or query operations