pub unsafe fn root_as_header_unchecked(buf: &[u8]) -> Header<'_>Expand description
Assumes, without verification, that a buffer of bytes contains a Header and returns it.
Safety
Callers must trust the given bytes do indeed contain a valid Header.