pub struct HttpFcbReader<T: AsyncHttpRangeClient + Send + Sync> { /* private fields */ }Expand description
FlatCityBuf dataset HTTP reader
Implementations
Sourceimpl HttpFcbReader<Client>
impl HttpFcbReader<Client>
pub async fn open(url: &str) -> Result<HttpFcbReader<Client>>
Sourceimpl<T: AsyncHttpRangeClient + Send + Sync> HttpFcbReader<T>
impl<T: AsyncHttpRangeClient + Send + Sync> HttpFcbReader<T>
pub async fn new( client: AsyncBufferedHttpRangeClient<T>, ) -> Result<HttpFcbReader<T>>
pub fn header(&self) -> Header<'_>
Sourcepub async fn select_all(self) -> Result<AsyncFeatureIter<T>>
pub async fn select_all(self) -> Result<AsyncFeatureIter<T>>
Select all features.
Sourcepub async fn select_query(self, query: Query) -> Result<AsyncFeatureIter<T>>
pub async fn select_query(self, query: Query) -> Result<AsyncFeatureIter<T>>
Select features within a bounding box.
Sourcepub async fn select_query_paged(
self,
query: Query,
limit: Option<usize>,
offset: Option<usize>,
) -> Result<AsyncFeatureIter<T>>
pub async fn select_query_paged( self, query: Query, limit: Option<usize>, offset: Option<usize>, ) -> Result<AsyncFeatureIter<T>>
Select features within a bounding box with optional pagination.
If limit/offset are provided, only a page of features is returned while
features_count() on the returned iterator still reflects the total number of matches.
Sourcepub async fn select_attr_query(
self,
query: &AttrQuery,
) -> Result<AsyncFeatureIter<T>>
pub async fn select_attr_query( self, query: &AttrQuery, ) -> Result<AsyncFeatureIter<T>>
This method uses the attribute index section to find matching feature offsets. It then groups (batches) the remote feature ranges in order to reduce IO overhead.
Sourcepub async fn select_attr_query_paged(
self,
query: &AttrQuery,
limit: Option<usize>,
offset: Option<usize>,
) -> Result<AsyncFeatureIter<T>>
pub async fn select_attr_query_paged( self, query: &AttrQuery, limit: Option<usize>, offset: Option<usize>, ) -> Result<AsyncFeatureIter<T>>
Attribute query with optional pagination where the iterator returns only the requested page,
while features_count() reflects the total number of matches.
pub fn add_indices_to_multi_http_index<C: AsyncHttpRangeClient + Send + Sync>( multi_index: &mut HttpMultiIndex<C>, columns: &[Column<'_>], attr_info: &AttributeIndex, index_begin: usize, feature_begin: usize, ) -> Result<()>