Max

Trait Max 

pub trait Max {
    // Required method
    fn max_value() -> Self;
}
Trait for types that have a maximum representable value.

This trait allows retrieval of the maximum value for a type, which is useful for B-tree operations like range queries and bounds checking.

Required Methods

fn max_value() -> Self

Returns the maximum representable value for this type.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl Max for DateTime<Utc>

Source

fn max_value() -> Self

Source

impl Max for bool

Source

fn max_value() -> Self

Source

impl Max for i8

Source

fn max_value() -> Self

Source

impl Max for i16

Source

fn max_value() -> Self

Source

impl Max for i32

Source

fn max_value() -> Self

Source

impl Max for i64

Source

fn max_value() -> Self

Source

impl Max for u8

Source

fn max_value() -> Self

Source

impl Max for u16

Source

fn max_value() -> Self

Source

impl Max for u32

Source

fn max_value() -> Self

Source

impl Max for u64

Source

fn max_value() -> Self

Implementors