pub struct FcbWriter<'a> { /* private fields */ }Expand description
Main writer for FlatCityBuf (FCB) format
FcbWriter handles the serialization of CityJSON data into the FCB binary format. It manages both header and feature writing, using a temporary file for feature storage before final assembly.
Implementations
Sourceimpl<'a> FcbWriter<'a>
impl<'a> FcbWriter<'a>
Sourcepub fn new(
cj: CityJSON,
header_option: Option<HeaderWriterOptions>,
attr_schema: Option<AttributeSchema>,
semantic_attr_schema: Option<AttributeSchema>,
) -> Result<Self>
pub fn new( cj: CityJSON, header_option: Option<HeaderWriterOptions>, attr_schema: Option<AttributeSchema>, semantic_attr_schema: Option<AttributeSchema>, ) -> Result<Self>
Sourcepub fn add_feature(&mut self, feature: &'a CityJSONFeature) -> Result<()>
pub fn add_feature(&mut self, feature: &'a CityJSONFeature) -> Result<()>